@@ -374,15 +374,15 @@ everything_except <- function(.DF, ..., .symbols = TRUE){
 #'
 #' This is a convenience function
 #' that allows grouping of a data frame by all variables (columns)
-#' except those variables specified in \code{...}.
+#' except those variables specified in `...`.
 #'
 #' @param .DF a data frame to be grouped
 #' @param ... a string, strings, vector of strings, or list of strings representing column names to be excluded from grouping
-#' @param add When \code{add = FALSE}, the default, \code{group_by()} will override existing groups.
-#'            To add to the existing groups, use \code{add = TRUE}.
-#' @param .drop When \code{.drop = TRUE}, empty groups are dropped.
+#' @param .add When `.add = FALSE`, the default, `dplyr::group_by()` will override existing groups.
+#'            To add to the existing groups, use `.add = TRUE`.
+#' @param .drop When `.drop = TRUE`, empty groups are dropped.
 #'
-#' @return a grouped version of \code{.DF}
+#' @return a grouped version of `.DF`
 #'
 #' @export
 #'
@@ -399,10 +399,10 @@ everything_except <- function(.DF, ..., .symbols = TRUE){
 #' group_by_everything_except(DF, c("a", "c")) %>% group_vars()
 #' group_by_everything_except(DF, c("a")) %>% group_vars()
 #' group_by_everything_except(DF, list("a")) %>% group_vars()
-group_by_everything_except <- function(.DF, ..., add = FALSE, .drop = FALSE){
+group_by_everything_except <- function(.DF, ..., .add = FALSE, .drop = FALSE){
   grouping_cols <- do.call(everything_except, list(.DF = .DF, ...))
   .DF %>%
-    dplyr::group_by(!!!grouping_cols, add = add, .drop = .drop)
+    dplyr::group_by(!!!grouping_cols, add = .add, .drop = .drop)
 }
 
 
